@@ -126,7 +126,7 @@ def fts_search(args, bindings) -> str:
     bindings["query"] = " AND ".join(fts_quote(args.include))
     if args.exclude:
         bindings["query"] += " NOT " + " NOT ".join(fts_quote(args.exclude))
-    table = "(" + args.db["media"].search_sql() + ")"  #  include_rank=True
+    table = "(" + args.db["media"].search_sql(include_rank=True) + ")"
     return table
 
 
