@@ -2,7 +2,6 @@ import argparse, json, sys
 from copy import deepcopy
 from datetime import datetime
 from pathlib import Path
-from sqlite3 import OperationalError
 from typing import Dict, List, Optional, Tuple
 
 import yt_dlp
@@ -219,7 +218,7 @@ def consolidate(v: dict) -> Optional[dict]:
 
 def log_problem(args, playlist_path) -> None:
     if is_playlist_known(args, playlist_path):
-        log.warning("Start of known playlist reached %s", playlist_path)
+        log.warning("\nStart of known playlist reached %s", playlist_path)
     else:
         log.warning("Could not add playlist %s", playlist_path)
 
@@ -379,17 +378,17 @@ def update_playlists(args, playlists):
         process_playlist(
             args,
             d["path"],
-            tube_opts(args, playlist_opts=d.get("dl_config", '{}'), func_opts={"ignoreerrors": "only_download"}),
+            tube_opts(args, playlist_opts=d.get("dl_config", "{}"), func_opts={"ignoreerrors": "only_download"}),
         )
 
         if args.extra:
             log.warning("[%s]: Getting extra metadata", d["path"])
-            get_extra_metadata(args, d["path"], playlist_dl_opts=d.get("dl_config", '{}'))
+            get_extra_metadata(args, d["path"], playlist_dl_opts=d.get("dl_config", "{}"))
 
 
 def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False) -> None:
     webpath = m["path"]
-    error = None if not error else error.replace(m.get("id",''), "").replace(" :", ":")
+    error = None if not error else error.replace(m.get("id", ""), "").replace(" :", ":")
     if not info:  # not downloaded
         entry = {
             "path": webpath,
@@ -457,8 +456,7 @@ def yt(args, m) -> None:
         def error(self, msg):
             ydl_log["error"].append(msg)
 
-    out_dir = lambda p: str(Path(args.prefix, m["category"], p))
-    Path(out_dir("tunnel_snakes_rule")).parent.mkdir(parents=True, exist_ok=True)
+    out_dir = lambda p: str(Path(args.prefix, m["category"] or "%(extractor_key,extractor)s", p))
     ydl_opts = tube_opts(
         args,
         func_opts={
@@ -483,7 +481,7 @@ def yt(args, m) -> None:
                 ),
             },
         },
-        playlist_opts=m.get("dl_config", '{}'),
+        playlist_opts=m.get("dl_config", "{}"),
     )
 
     download_archive = Path("~/.local/share/yt_archive.txt").resolve()
